@@ -161,14 +161,21 @@ void TextHandlerTest::initTestCase()
 
 void TextHandlerTest::allowedAttributes()
 {
-    const QString testInputString = QStringLiteral("<p><span data-mx-spoiler><font color=#FFFFFF>Test</font><span></p>");
-    const QString testOutputString = QStringLiteral("<p><span data-mx-spoiler><font color=#FFFFFF>Test</font><span></p>");
+    const QString testInputString1 = QStringLiteral("<p><span data-mx-spoiler><font color=#FFFFFF>Test</font><span></p>");
+    const QString testOutputString1 = QStringLiteral("<p><span data-mx-spoiler><font color=#FFFFFF>Test</font><span></p>");
+    // Handle urls where the href has either single (') or double (") quotes.
+    const QString testInputString2 = QStringLiteral("<p><a href=\"https://kde.org\">link</a><a href='https://kde.org'>link</a></p>");
+    const QString testOutputString2 = QStringLiteral("<p><a href=\"https://kde.org\">link</a><a href='https://kde.org'>link</a></p>");
 
     TextHandler testTextHandler;
-    testTextHandler.setData(testInputString);
+    testTextHandler.setData(testInputString1);
 
-    QCOMPARE(testTextHandler.handleSendText(), testOutputString);
-    QCOMPARE(testTextHandler.handleRecieveRichText(), testOutputString);
+    QCOMPARE(testTextHandler.handleSendText(), testOutputString1);
+    QCOMPARE(testTextHandler.handleRecieveRichText(), testOutputString1);
+
+    testTextHandler.setData(testInputString2);
+    QCOMPARE(testTextHandler.handleSendText(), testOutputString2);
+    QCOMPARE(testTextHandler.handleRecieveRichText(), testOutputString2);
 }
 
 void TextHandlerTest::stripDisallowedTags()
@@ -319,11 +326,19 @@ void TextHandlerTest::receivePlainTextIn()
     const QString testOutputStringRich = QStringLiteral("&lt;plain text in tag bracket&gt;<br>Test link <a href=\"https://kde.org\">https://kde.org</a>.");
     QString testOutputStringPlain = QStringLiteral("<plain text in tag bracket>\nTest link https://kde.org.");
 
+    // Make sure quotes are maintained in a plain string.
+    const QString testInputString2 = QStringLiteral("last line is \"Time to switch to a new topic.\"");
+    const QString testOutputString2 = QStringLiteral("last line is \"Time to switch to a new topic.\"");
+
     TextHandler testTextHandler;
     testTextHandler.setData(testInputString);
 
     QCOMPARE(testTextHandler.handleRecieveRichText(Qt::PlainText), testOutputStringRich);
     QCOMPARE(testTextHandler.handleRecievePlainText(), testOutputStringPlain);
+
+    testTextHandler.setData(testInputString2);
+    QCOMPARE(testTextHandler.handleRecieveRichText(Qt::PlainText), testOutputString2);
+    QCOMPARE(testTextHandler.handleRecievePlainText(), testOutputString2);
 }
 
 void TextHandlerTest::receiveStripNewlines()
@@ -332,6 +347,9 @@ void TextHandlerTest::receiveStripNewlines()
     const QString testInputStringRich = QStringLiteral("Test<br>many<br />new<br>lines.");
     const QString testOutputString = QStringLiteral("Test many new lines.");
 
+    const QString testInputStringPlain2 = QStringLiteral("* List\n* Items");
+    const QString testOutputString2 = QStringLiteral("List Items");
+
     TextHandler testTextHandler;
     testTextHandler.setData(testInputStringPlain);
 
@@ -339,9 +357,11 @@ void TextHandlerTest::receiveStripNewlines()
     QCOMPARE(testTextHandler.handleRecieveRichText(Qt::PlainText, nullptr, nullptr, true), testOutputString);
 
     testTextHandler.setData(testInputStringRich);
-
     QCOMPARE(testTextHandler.handleRecievePlainText(Qt::RichText, true), testOutputString);
     QCOMPARE(testTextHandler.handleRecieveRichText(Qt::RichText, nullptr, nullptr, true), testOutputString);
+
+    testTextHandler.setData(testInputStringPlain2);
+    QCOMPARE(testTextHandler.handleRecievePlainText(Qt::RichText, true), testOutputString2);
 }
 
 /**
