@@ -8,9 +8,13 @@
 #include "neochatroom.h"
 #include <KLocalizedString>
 #include <QDesktopServices>
-#include <QStandardPaths>
-#include <qt_connection_util.h>
 #include <QQuickTextDocument>
+#include <QStandardPaths>
+#include <csapi/joining.h>
+#ifdef QUOTIENT_07
+#include <csapi/knocking.h>
+#endif
+#include <qt_connection_util.h>
 #include <user.h>
 
 #ifndef Q_OS_ANDROID
@@ -124,7 +128,10 @@ void RoomManager::openRoomForActiveConnection()
 
 void RoomManager::enterRoom(NeoChatRoom *room)
 {
-    if (m_chatDocumentHandler) {
+    if (m_currentRoom && !m_currentRoom->chatBoxEditId().isEmpty()) {
+        m_currentRoom->setChatBoxEditId("");
+    }
+    if (m_currentRoom && m_chatDocumentHandler) {
         // We're doing these things here because it is critical that they are switched at the same time
         m_currentRoom->setSavedText(m_chatDocumentHandler->document()->textDocument()->toPlainText());
         m_chatDocumentHandler->setRoom(room);
@@ -193,12 +200,39 @@ void RoomManager::visitRoom(Room *room, const QString &eventId)
 
 void RoomManager::joinRoom(Quotient::Connection *account, const QString &roomAliasOrId, const QStringList &viaServers)
 {
-    account->joinRoom(QUrl::toPercentEncoding(roomAliasOrId), viaServers);
-    connectSingleShot(account, &Quotient::Connection::newRoom, this, [this](Quotient::Room *room) {
-        enterRoom(dynamic_cast<NeoChatRoom *>(room));
+    auto job = account->joinRoom(QUrl::toPercentEncoding(roomAliasOrId), viaServers);
+    connectSingleShot(job, &Quotient::BaseJob::finished, this, [this, account](Quotient::BaseJob *finish) {
+        if (finish->status() == Quotient::BaseJob::Success) {
+            connectSingleShot(account, &Quotient::Connection::newRoom, this, [this](Quotient::Room *room) {
+                enterRoom(dynamic_cast<NeoChatRoom *>(room));
+            });
+        } else {
+            Q_EMIT warning(i18n("Failed to join room"), finish->errorString());
+        }
     });
 }
 
+// TODO: maybe need use the function upstream later
+#ifdef QUOTIENT_07
+void RoomManager::knockRoom(Quotient::Connection *account, const QString &roomAliasOrId, const QString &reason, const QStringList &viaServers)
+{
+    auto *const job = account->callApi<KnockRoomJob>(roomAliasOrId, viaServers, reason);
+    // Upon completion, ensure a room object is created in case it hasn't come
+    // with a sync yet. If the room object is not there, provideRoom() will
+    // create it in Join state. finished() is used here instead of success()
+    // to overtake clients that may add their own slots to finished().
+    connectSingleShot(job, &BaseJob::finished, this, [this, job, account] {
+        if (job->status() == Quotient::BaseJob::Success) {
+            connectSingleShot(account, &Quotient::Connection::newRoom, this, [this](Quotient::Room *room) {
+                Q_EMIT currentRoom()->showMessage(NeoChatRoom::Info, i18n("You requested to join '%1'", room->name()));
+            });
+        } else {
+            Q_EMIT warning(i18n("Failed to request joining room"), job->errorString());
+        }
+    });
+}
+#endif
+
 bool RoomManager::visitNonMatrix(const QUrl &url)
 {
 #ifdef Q_OS_ANDROID
